import { useState, ChangeEvent } from "react";
import {
  Box,
  FormControl,
  FormControlLabel,
  FormLabel,
  Radio,
  RadioGroup,
  Tooltip,
  Typography, useTheme,
} from "@mui/material";

import InfoIcon from "@icons/InfoIcon";

import type { QuizQuestionEmoji } from "model/questionTypes/emoji";
import RadioCheck from "@ui_kit/RadioCheck";
import RadioIcon from "@ui_kit/RadioIcon";

interface Props {
  question: QuizQuestionEmoji;
}

export default function Emoji({ question }: Props) {
  const [value, setValue] = useState<string | null>(null);
  const theme = useTheme();
  const handleChange = (event: ChangeEvent<HTMLInputElement>) => {
    setValue((event.target as HTMLInputElement).value);
  };

  return (
    <FormControl fullWidth>
      <FormLabel id="quiz-question-radio-group" data-cy="question-title" sx={{fontSize: "24px", fontWeight: 500, marginBottom: "25px"}}>{question.title}</FormLabel>
      <RadioGroup
        aria-labelledby="quiz-question-radio-group"
        value={value}
        onChange={handleChange}
        sx={{display: "flex",
        flexDirection: "row", gap: "42px"}}
      >
        {question.content.variants
          .filter(({ answer }) => answer)
          .map((variant, index) => (
              <Box
                  key={index}
                  sx={{
                    borderRadius: "12px",
                    border: `1px solid ${theme.palette.grey2.main}`,
                    overflow: "hidden",
                    maxWidth: "317px",
                    width: "100%",
                    height: "255px"
                  }}
              >
                <Box
                    sx={{ display: "flex", alignItems: "center", height: "193px", background: "#ffffff" }}
                >
                  <Box sx={{ width: "100%", display: "flex", justifyContent: "center" }}>
                    {variant.extendedText && (
                        <Typography fontSize={"100px"}>{`${variant.extendedText}`}</Typography>
                    )}
                  </Box>
                </Box>
                <FormControlLabel
                    key={index}
                    value={variant.answer}
                    sx={{
                      margin: 0,
                      padding: "15px",
                      color: "#4D4D4D",
                      display: "flex",
                      gap: "10px",
                      background: "#f2f3f7"
                    }}
                    control={
                      <Radio
                          inputProps={{
                            "data-cy": "variant-radio",
                          }}
                          checkedIcon={<RadioCheck />} icon={<RadioIcon />}

                      />
                    }
                    label={
                      <Box sx={{ display: "flex", alignItems: "center", gap: 2 }} data-cy="variant-answer">
                        <Typography>{`${variant.answer}`}</Typography>
                        {variant.hints && (
                            <Tooltip title="Подсказка" placement="right">
                              <Box>
                                <InfoIcon />
                              </Box>
                            </Tooltip>
                        )}
                      </Box>
                    }
                />
              </Box>
          ))}
      </RadioGroup>
    </FormControl>
  );
}
