import { useState, ChangeEvent } from "react";
import {
    Box,
    FormControl,
    FormControlLabel,
    FormLabel,
    Radio,
    RadioGroup,
    Tooltip,
    Typography, useTheme,
} from "@mui/material";

import InfoIcon from "@icons/InfoIcon";

import type { QuestionVariant } from "model/questionTypes/shared";
import type { QuizQuestionVarImg } from "model/questionTypes/varimg";
import RadioCheck from "@ui_kit/RadioCheck";
import RadioIcon from "@ui_kit/RadioIcon";

interface Props {
  question: QuizQuestionVarImg;
}

export default function Varimg({ question }: Props) {
  const [selectedVariantIndex, setSelectedVariantIndex] = useState<number>(-1);
    const theme = useTheme();
  const handleChange = (event: ChangeEvent<HTMLInputElement>) => {
    setSelectedVariantIndex(
      question.content.variants.findIndex(
        (variant) => variant.answer === event.target.value
      )
    );
  };

  const currentVariant: QuestionVariant | undefined =
    question.content.variants[selectedVariantIndex];

  return (
    <Box
      sx={{
        display: "flex",
        flexWrap: "wrap",
        gap: "40px",
      }}
    >
      <FormControl sx={{maxWidth: "900px",
          width: "100%", gap: "25px"}}>
        <FormLabel 
            id="quiz-question-radio-group"
            data-cy="question-title"
            sx={{fontSize: "24px", fontWeight: 500}}
        >
            {question.title}
        </FormLabel>
        <RadioGroup
          aria-labelledby="quiz-question-radio-group"
          value={currentVariant?.answer ?? ""}
          onChange={handleChange}
          sx={{gap: "20px"}}
        >
          {question.content.variants
            .filter(({ answer }) => answer)
            .map((variant, index) => (
              <FormControlLabel
                key={index}
                value={variant.answer}
                data-cy="variant-answer"
                sx={{
                    margin: 0,
                    borderRadius: "5px",
                    padding: "15px",
                    color: "#4D4D4D",
                    border: `1px solid ${theme.palette.grey2.main}`,
                    display: "flex",
                }}
                control={
                    <Radio 
                        inputProps={{
                            "data-cy": "variant-radio",
                        }}
                        checkedIcon={<RadioCheck />} icon={<RadioIcon />}
                    />
                }
                label={
                  <Box sx={{ display: "flex", alignItems: "center", gap: 2 }}>
                    <Typography>{variant.answer}</Typography>
                    {variant.hints && (
                      <Tooltip title={variant.hints} placement="right">
                        <Box>
                          <InfoIcon />
                        </Box>
                      </Tooltip>
                    )}
                  </Box>
                }
              />
            ))}
        </RadioGroup>
      </FormControl>
      <Box
        sx={{
          border: "1px solid #E3E3E3",
          maxWidth: "400px",
          height: "400px",
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
          borderRadius: "12px",
          marginTop: "50px",
          overflow: "hidden",
        }}
      >
        {currentVariant?.extendedText ? (
          <img
            src={currentVariant.extendedText}
            data-cy="variant-image"
            alt="question variant"
            style={{
              width: "100%",
              display: "block",
              objectFit: "scale-down",
              flexGrow: 1,
            }}
          />
        ) : (
          <Typography p={2}>
            {selectedVariantIndex === -1
              ? "Выберите вариант"
              : "Картинка отсутствует"}
          </Typography>
        )}
      </Box>
    </Box>
  );
}
